@@ -1,4 +1,4 @@
-%%%  This code was developped by Zhihui Jiao(jzhihui521@gmail.com).
+%%%  This code was developed by Zhihui Jiao(jzhihui521@gmail.com).
 %%%
 %%%  Copyright (C) 2013 Zhihui Jiao
 %%%
@@ -27,7 +27,7 @@
 -vc('$Id$ ').
 -author('jzhihui521@gmail.com').
 
--export([get_handshake/5, check_handshake/2, encode_binary/1, encode_text/1,
+-export([get_handshake/6, check_handshake/2, encode_binary/1, encode_text/1,
          encode_close/1, encode/2, decode/1]).
 
 -include("ts_profile.hrl").
@@ -37,7 +37,7 @@
 %%%===================================================================
 %%% API functions
 %%%===================================================================
-get_handshake(Host, Path, SubProtocol, Version, Origin) ->
+get_handshake(Host, Path, SubProtocol, Version, Origin, Headers) ->
     {Key, Accept} = gen_accept_key(),
     Req = list_to_binary(["GET ", Path, " HTTP/1.1\r\n",
                           "Host: ", Host ,"\r\n",
@@ -48,7 +48,8 @@ get_handshake(Host, Path, SubProtocol, Version, Origin) ->
                                          _  -> Origin
                           end, "\r\n",
                           "Sec-WebSocket-Key: ", Key, "\r\n",
-                          "Sec-WebSocket-Version: ", Version, "\r\n"]),
+                          "Sec-WebSocket-Version: ", Version, "\r\n",
+                          headers(Headers)]),
     SubProHeader = case SubProtocol of
         [] -> [];
         _ -> "Sec-WebSocket-Protocol: " ++ SubProtocol ++ "\r\n"
@@ -105,7 +106,7 @@ encode_text(Data) ->
     encode(Data, ?OP_TEXT).
 
 encode_close(Reason) ->
-    %% According RFC6455, we shoud add a status code for close frame,
+    %% According RFC6455, we should add a status code for close frame,
     %% check here: http://tools.ietf.org/html/rfc6455#section-7.4,
     %% we add a normal closure status code 1000 here.
     StatusCode = <<3, 232>>,
@@ -196,3 +197,18 @@ parse_frame(<< 1:1, % FIN
     parse_payload(Opcode, MaskLengthAndPayload);
 parse_frame(_Data) ->
     more.
+
+% user defined headers
+headers([]) -> [];
+headers(Headers) ->
+    HeadersToIgnore = ["host", "upgrade", "connection", "origin",
+                       "sec-websocket-key", "sec-websocket-version",
+                       "sec-websocket-protocol"],
+    lists:foldl(fun({Name, Value}, Result) ->
+        case lists:member(string:to_lower(Name), HeadersToIgnore) of
+            true ->
+                Result;
+            _ ->
+                [Name, ": ", Value, ?CRLF | Result]
+        end
+    end, [], lists:reverse(Headers)).
