@@ -17,7 +17,8 @@
 %%%  In addition, as a special exception, you have the permission to
 %%%  link the code of this program with any library released under
 %%%  the EPL license and distribute linked combinations including
-%%%  the two.
+%%%  the two; the MPL (Mozilla Public License), which EPL (Erlang
+%%%  Public License) is based on, is included in this exception.
 
 %%% @copyright (C) 2008  Pablo Polvorin <pablo.polvorin@process-one.net>
 %%% @author Pablo Polvorin <pablo.polvorin@process-one.net>
@@ -56,7 +57,7 @@ new(VarNames, Values) when is_list(VarNames),is_list(Values)->
     end.
 
 %% @spec lookup(Key::atom(), Dynvar::dynvars()) -> {ok,Value::term()} | false
-lookup(Key, []) ->
+lookup(_Key, []) ->
     false;
 lookup(Key, DynVars) when ?IS_DYNVARS(DynVars), is_atom(Key)->
     case lists:keysearch(Key,1,DynVars) of
@@ -118,4 +119,6 @@ do_map(Fun,Key,Default,[H|Rest], Acc) ->
 %% @spec merge(DynVars::dynvars(),DynVars::dynvars()) -> dynvars()
 %% @doc merge two set of dynamic variables
 merge(DynVars1, DynVars2) when ?IS_DYNVARS(DynVars1),?IS_DYNVARS(DynVars2) ->
-    ts_utils:keyumerge(1,DynVars1,DynVars2).
+    ts_utils:keyumerge(1,DynVars1,DynVars2);
+merge(_, DynVars2) -> DynVars2.
+
