@@ -32,7 +32,8 @@
 -author('nicolas.niclausse@niclux.org').
 
 -export([parse_config/2, parse_URL/1, set_port/1, set_scheme/1,
-         check_user_agent_sum/1, set_query/1, encode_ipv6_address/1]).
+         check_user_agent_sum/1, set_query/1, encode_ipv6_address/1,
+         parse_headers/2]).
 
 -include("ts_profile.hrl").
 -include("ts_http.hrl").
@@ -67,7 +68,7 @@ parse_config(Element = #xmlElement{name=http},
                    [] -> false;
                    _  -> true
                end,
-    %% Apache Tomcat applications need content-type informations to read post forms
+    %% Apache Tomcat applications need content-type information to read post forms
     ContentType = ts_config:getAttr(string,Element#xmlElement.attributes,
                              content_type, "application/x-www-form-urlencoded"),
     Date   = ts_config:getAttr(string, Element#xmlElement.attributes,
@@ -119,7 +120,7 @@ parse_config(Element = #xmlElement{name=http},
                                               realm, undefined),
                   QOP = ts_config:getAttr(string,AuthEl#xmlElement.attributes,
                                               qop, undefined),
-                  ?LOGF("DIGEST ? : ~p ~p ~p", [Type, Nonce, Realm], ?WARN),
+                  ?DebugF("DIGEST ? : ~p ~p ~p", [Type, Nonce, Realm]),
                   Request3#http_request{userid=UserId, passwd=Passwd,
                                         auth_type=Type, digest_nonce=Nonce,
                                         digest_cnonce=Cnonce, digest_nc=Nc,
@@ -209,6 +210,12 @@ get_previous_http_server(Ets, Id) ->
         [{_Key,PrevServ}] -> PrevServ
     end.
 
+%%----------------------------------------------------------------------
+%% Func: parse_headers/2
+%% Args: Elements (list), Headers (list)
+%% Returns: List
+%% Purpose: parse http_header elements
+%%----------------------------------------------------------------------
 parse_headers([], Headers) ->
     Headers;
 parse_headers([Element = #xmlElement{name=http_header} | Tail], Headers) ->
@@ -239,11 +246,11 @@ parse_cookie([_| Tail], Cookies) ->
 %% Func: set_msg/2
 %% Returns: #ts_request record
 %% Purpose: build the #ts_request record from an #http_request,
-%%          and Substition def.
+%%          and Substitution def.
 %%----------------------------------------------------------------------
 %% if the URL is full (http://...), we parse it and get server host,
 %% port and scheme from the URL and override the global setup of the
-%% server. These informations are stored in the #ts_request record.
+%% server. These information are stored in the #ts_request record.
 set_msg(HTTP=#http_request{url="http" ++ URL},
         {SubstFlag, MatchRegExp, UseProxy, [Server|_], _PrevHTTPServer, Tab, Id}) ->
     case {SubstFlag, re:run(URL, "%%.+%%")} of
@@ -347,7 +354,7 @@ set_port(#url{port=Port}) -> integer_to_list(Port).
 %% @spec set_scheme({http|https,gen_tcp|gen_tcp6|ssl|ssl6})-> gen_tcp|gen_tcp6|ssl|ssl6
 %% @doc set scheme for given protocol and server setup. If the main
 %% server is configured with IPv6, we assume that the we should also
-%% use IPv6 for the given absolut URL
+%% use IPv6 for the given absolute URL
 %% @end
 set_scheme({http, ts_tcp6})  -> ts_tcp6;
 set_scheme({http, ts_ssl6})  -> ts_tcp6;
@@ -391,6 +398,8 @@ parse_URL(host, [], Acc, URL) -> % no path or port
     URL#url{host=lists:reverse(Acc), path= "/"};
 parse_URL(host, [$/|Tail], Acc, URL) -> % path starts here
     parse_URL(path, Tail, "/", URL#url{host=lists:reverse(Acc)});
+parse_URL(host, [$?|Tail], Acc, URL) -> % path/query starts here
+    parse_URL(path, "?" ++ Tail, "/", URL#url{host=lists:reverse(Acc)});
 parse_URL(host, [$:|Tail], Acc, URL) -> % port starts here
     parse_URL(port, Tail, [], URL#url{host=lists:reverse(Acc)});
 parse_URL(host, [H|Tail], Acc, URL) ->
