@@ -1,4 +1,4 @@
-%%%  This code was developped by IDEALX (http://IDEALX.org/) and
+%%%  This code was developed by IDEALX (http://IDEALX.org/) and
 %%%  contributors (their names can be found in the CONTRIBUTORS file).
 %%%  Copyright (C) 2000-2004 IDEALX
 %%%
@@ -41,9 +41,9 @@
 -include("ts_config.hrl").
 
 %% External exports
--export([start/1, stop/0, newclient/1, endclient/1, sendmes/1, add/2,
-         start_clients/1, abort/0, status/0, rcvmes/1, add/1, dumpstats/0,
-         add_match/2, dump/1, launcher_is_alive/0
+-export([start/1, stop/0, newclient/1, endclient/1, sendmes/1,
+         start_clients/1, abort/0, status/0, rcvmes/1, dumpstats/0,
+         dump/1, launcher_is_alive/0
         ]).
 
 %% gen_server callbacks
@@ -104,20 +104,6 @@ start_clients({Machines, Dump, BackEnd}) ->
 stop() ->
     gen_server:cast({global, ?MODULE}, {stop}).
 
-add(nocache,Data) ->
-    gen_server:cast({global, ?MODULE}, {add, Data}).
-
-
-add(Data) ->
-    ts_mon_cache:add(Data).
-
-add_match(Data,{UserId,SessionId,RequestId,Tr,Name}) ->
-    add_match(Data,{UserId,SessionId,RequestId,[],Tr,Name});
-add_match(Data=[Head|_],{UserId,SessionId,RequestId,Bin,Tr,Name}) ->
-    TimeStamp=?NOW,
-    put(last_match,Head),
-    ts_mon_cache:add_match(Data,{UserId,SessionId,RequestId,TimeStamp, Bin,Tr,Name}).
-
 status() ->
     gen_server:call({global, ?MODULE}, {status}).
 
@@ -137,19 +123,19 @@ sendmes({none, _, _})       -> skip;
 sendmes({protocol, _, _})   -> skip;
 sendmes({protocol_local, _, _})   -> skip;
 sendmes({_Type, Who, What}) ->
-    gen_server:cast({global, ?MODULE}, {sendmsg, Who, ?NOW, What}).
+    gen_server:cast({global, ?MODULE}, {sendmsg, Who, ?TIMESTAMP, What}).
 
 rcvmes({none, _, _})    -> skip;
 rcvmes({protocol, _, _})-> skip;
 rcvmes({protocol_local, _, _})-> skip;
 rcvmes({_, _, closed})  -> skip;
 rcvmes({_Type, Who, What})  ->
-    gen_server:cast({global, ?MODULE}, {rcvmsg, Who, ?NOW, What}).
+    gen_server:cast({global, ?MODULE}, {rcvmsg, Who, ?TIMESTAMP, What}).
 
 dump({none, _, _})-> skip;
 dump({cached, << >> })-> skip;
 dump({_Type, Who, What})  ->
-    gen_server:cast({global, ?MODULE}, {dump, Who, ?NOW, What});
+    gen_server:cast({global, ?MODULE}, {dump, Who, ?TIMESTAMP, What});
 dump({cached, Data})->
     gen_server:cast({global, ?MODULE}, {dump, cached, Data}).
 
@@ -182,7 +168,7 @@ init([LogDir]) ->
             {ok, State#state{log=standard_io}};
         Name ->
             Filename = filename:join(LogDir, Name),
-            case file:open(Filename,[write]) of
+            case file:open(Filename,[append]) of
                 {ok, Stream} ->
                     ?LOG("starting monitor~n",?INFO),
                     {ok, State#state{log=Stream}};
@@ -393,7 +379,7 @@ close_stats(State) ->
         json ->
             io:format(State#state.log,"]}]}~n",[]);
         _ ->
-            io:format(State#state.log,"EndMonitor:~w~n",[?NOW])
+            io:format(State#state.log,"EndMonitor:~w~n",[?TIMESTAMP])
         end,
     case State#state.log of
         standard_io -> ok;
