@@ -157,10 +157,10 @@ handle_cast({record, {Request}}, State=#state_rec{timestamp=0,plugin=Plugin}) ->
     io:format(State#state_rec.logfd,"<session name='~s' probability='100' "++
               " type='~s'>~n",["rec"++Name, Type]),
     {ok, NewState} = Plugin:record_request(State, Request),
-    {noreply, NewState#state_rec{timestamp=now()}};
+    {noreply, NewState#state_rec{timestamp=?NOW}};
 
 handle_cast({record, {Request}}, State=#state_rec{plugin=Plugin}) ->
-    TimeStamp=now(),
+    TimeStamp=?NOW,
     Elapsed = ts_utils:elapsed(State#state_rec.timestamp,TimeStamp),
     case Elapsed < State#state_rec.thinktime_low of
         true ->
